==> kadaster-gds2-2.5-sources.jar: nl/kadaster/schemas/gds2/service/afgifte_bestandenlijstopvragen/v20170401/BestandenlijstOpvragenResponse.java <==

package nl.kadaster.schemas.gds2.service.afgifte_bestandenlijstopvragen.v20170401;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import nl.kadaster.schemas.gds2.afgifte_bestandenlijstopvragenresultaat.v20170401.BestandenlijstOpvragenResultaatType;


/**
 * &lt;p&gt;Java class for anonymous complex type.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * 
 * &lt;pre&gt;
 * &amp;lt;complexType&amp;gt;
 *   &amp;lt;complexContent&amp;gt;
 *     &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&amp;gt;
 *       &amp;lt;sequence&amp;gt;
 *         &amp;lt;element name="antwoord" type="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstopvragenresultaat/v20170401}BestandenlijstOpvragenResultaatType"/&amp;gt;
 *       &amp;lt;/sequence&amp;gt;
 *     &amp;lt;/restriction&amp;gt;
 *   &amp;lt;/complexContent&amp;gt;
 * &amp;lt;/complexType&amp;gt;
 * &lt;/pre&gt;
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "antwoord"
})
@XmlRootElement(name = "BestandenlijstOpvragenResponse")
public class BestandenlijstOpvragenResponse {

    @XmlElement(required = true)
    protected BestandenlijstOpvragenResultaatType antwoord;

    /**
     * Gets the value of the antwoord property.
     * 
     * @return
     *     possible object is
     *     {@link BestandenlijstOpvragenResultaatType }
     *     
     */
    public BestandenlijstOpvragenResultaatType getAntwoord() {
        return antwoord;
    }

    /**
     * Sets the value of the antwoord property.
     * 
     * @param value
     *     allowed object is
     *     {@link BestandenlijstOpvragenResultaatType }
     *     
     */
    public void setAntwoord(BestandenlijstOpvragenResultaatType value) {
        this.antwoord = value;
    }

}

==> kadaster-gds2-2.7-sources.jar: nl/kadaster/schemas/gds2/service/afgifte_bestandenlijstopvragen/v20170401/BestandenlijstOpvragenResponse.java <==

package nl.kadaster.schemas.gds2.service.afgifte_bestandenlijstopvragen.v20170401;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import nl.kadaster.schemas.gds2.afgifte_bestandenlijstopvragenresultaat.v20170401.BestandenlijstOpvragenResultaatType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="antwoord" type="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstopvragenresultaat/v20170401}BestandenlijstOpvragenResultaatType"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "antwoord"
})
@XmlRootElement(name = "BestandenlijstOpvragenResponse")
public class BestandenlijstOpvragenResponse {

    @XmlElement(required = true)
    protected BestandenlijstOpvragenResultaatType antwoord;

    /**
     * Gets the value of the antwoord property.
     * 
     * @return
     *     possible object is
     *     {@link BestandenlijstOpvragenResultaatType }
     *     
     */
    public BestandenlijstOpvragenResultaatType getAntwoord() {
        return antwoord;
    }

    /**
     * Sets the value of the antwoord property.
     * 
     * @param value
     *     allowed object is
     *     {@link BestandenlijstOpvragenResultaatType }
     *     
     */
    public void setAntwoord(BestandenlijstOpvragenResultaatType value) {
        this.antwoord = value;
    }

}
